@@ -2,9 +2,9 @@ use strict;
 use warnings;
 package Dist::Zilla::App::Command::stale;
 # ABSTRACT: print your distribution's prerequisites and plugins that are out of date
-# vim: set ts=8 sts=4 sw=4 tw=78 et :
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.045';
+our $VERSION = '0.046';
 
 use Dist::Zilla::App -command;
 
@@ -119,10 +119,13 @@ sub execute
 
     return if not $zilla;
 
+    my $error;
     my @stale_modules = Try::Tiny::try {
         $self->stale_modules($zilla, $opt->all);
     }
     Try::Tiny::catch {
+        $error = $_;
+
         # if there was an error during the build, fall back to fetching
         # authordeps, in the hopes that we can report something helpful
         $self->_missing_authordeps;
@@ -130,6 +133,7 @@ sub execute
 
     $self->app->chrome->logger->unmute;
     $self->log(join("\n", @stale_modules));
+    $self->log([ 'got error from stale_modules check: %s', $error ]) if $error and not @stale_modules;
 }
 
 sub _missing_authordeps
@@ -163,7 +167,7 @@ Dist::Zilla::App::Command::stale - print your distribution's prerequisites and p
 
 =head1 VERSION
 
-version 0.045
+version 0.046
 
 =head1 SYNOPSIS
 
@@ -217,7 +221,7 @@ L<Dist::Zilla::Plugin::PromptIfStale>
 
 Karen Etheridge <ether@cpan.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2013 by Karen Etheridge.
 
