@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.044-9-gd2196aa
+package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.045-14-gc74192e
 # ABSTRACT: Check at build/release time if modules are out of date
 # KEYWORDS: prerequisites upstream dependencies modules metadata update stale
-# vim: set ts=8 sts=4 sw=4 tw=78 et :
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.045';
+our $VERSION = '0.046';
 
 use Moose;
 with 'Dist::Zilla::Role::BeforeBuild',
@@ -85,9 +85,11 @@ around dump_config => sub
     my $config = $self->$orig;
 
     $config->{+__PACKAGE__} = {
-        (map { $_ => ($self->$_ || 0) } qw(phase check_all_plugins check_all_prereqs)),
-        skip => [ $self->skip ],
-        modules => [ $self->_raw_modules ],
+        (map { $_ => $self->$_ ? 1 : 0 } qw(check_all_plugins check_all_prereqs)),
+        phase => $self->phase,
+        skip => [ sort $self->skip ],
+        modules => [ sort $self->_raw_modules ],
+        blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
     };
 
     return $config;
@@ -458,7 +460,7 @@ Dist::Zilla::Plugin::PromptIfStale - Check at build/release time if modules are
 
 =head1 VERSION
 
-version 0.045
+version 0.046
 
 =head1 SYNOPSIS
 
@@ -594,7 +596,7 @@ Karen Etheridge <ether@cpan.org>
 
 David Golden <dagolden@cpan.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2013 by Karen Etheridge.
 
